pub enum RoundEvent {
KickoffUtxoUsed {
kickoff_idx: usize,
kickoff_outpoint: OutPoint,
},
ReadyToReimburseSent {
round_idx: RoundIndex,
},
RoundSent {
round_idx: RoundIndex,
},
OperatorExit,
SavedToDb,
SetChallenged {
round_idx: RoundIndex,
},
}Expand description
Events that change the state of the round state machine.
Variants
KickoffUtxoUsed
Event that is dispatched when a kickoff utxo in a round tx is spent.
ReadyToReimburseSent
Event that is dispatched when the next ready to reimburse tx is mined.
Fields
round_idx: RoundIndexRoundSent
Event that is dispatched when the next round tx is mined.
Fields
round_idx: RoundIndexOperatorExit
This event is sent if operators collateral was spent in any way other than default behaviour (default is round -> ready to reimburse -> round -> ready to reimburse -> …) It means operator stopped participating in the protocol and can no longer participate in clementine bridge protocol.
SavedToDb
Special event that is used to indicate that the state machine has been saved to the database and the dirty flag should be reset to false
SetChallenged
Event to flag that the current round is challenged, it should only be sent and handled if current state is round_tx
Fields
round_idx: RoundIndexTrait Implementations
Sourceimpl Clone for RoundEvent
impl Clone for RoundEvent
Sourcefn clone(&self) -> RoundEvent
fn clone(&self) -> RoundEvent
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RoundEvent
impl Debug for RoundEvent
Sourceimpl<'de> Deserialize<'de> for RoundEvent
impl<'de> Deserialize<'de> for RoundEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Hash for RoundEvent
impl Hash for RoundEvent
Sourceimpl Ord for RoundEvent
impl Ord for RoundEvent
Sourcefn cmp(&self, other: &RoundEvent) -> Ordering
fn cmp(&self, other: &RoundEvent) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for RoundEvent
impl PartialEq for RoundEvent
Sourceimpl PartialOrd for RoundEvent
impl PartialOrd for RoundEvent
Sourceimpl Serialize for RoundEvent
impl Serialize for RoundEvent
impl Eq for RoundEvent
impl StructuralPartialEq for RoundEvent